Module river_layout_v3

Module river_layout_v3 

receive and respond to layout demands

This interface allows clients to receive layout demands from the compositor for a specific output and subsequently propose positions and dimensions of individual views.

Structs

LayoutDemandArgs
RiverLayoutV3
receive and respond to layout demands

Enums

Error
Event
The event enum for RiverLayoutV3